@@ -1,20 +1,7 @@
 /*
-	Copyright (C) 2003-2008 Cies Breijs <cies AT kde DOT nl>
+    SPDX-FileCopyrightText: 2003-2008 Cies Breijs <cies AT kde DOT nl>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
-
-	You should have received a copy of the GNU General Public
-	License along with this program; if not, write to the Free
-	Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-	Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef _EDITOR_H_
@@ -58,7 +45,7 @@ class LineNumbers : public QWidget
 
 	public:
 		LineNumbers(QWidget *parent, QTextEdit *te) : QWidget(parent), editor(te), maxWidth(0) {}
-        ~LineNumbers() Q_DECL_OVERRIDE {}
+        ~LineNumbers() override {}
 	
 		void setFont(const QFont& f) { QWidget::setFont(f); }
 
@@ -70,7 +57,7 @@ class LineNumbers : public QWidget
 			setFixedWidth(fontMetrics().boundingRect(s).width() + 2*LINENUMBER_SPACING);
 		}
 
-		void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE {
+		void paintEvent(QPaintEvent*) override {
 			QAbstractTextDocumentLayout* layout = editor->document()->documentLayout();
 			int contentsY = editor->verticalScrollBar()->value();
 			qreal pageBottom = contentsY + editor->viewport()->height();
@@ -143,15 +130,19 @@ class TextEdit : public QTextEdit
 		}
 
 	protected:
-		void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE {
+		void paintEvent(QPaintEvent *event) override {
 			QPainter painter(viewport());
-			painter.fillRect(currentLineRect(), QBrush(LINE_HIGHLIGHT_COLOR));
-			if (!currentWord.isNull())
-				foreach (const QRect &rect, coordsToRects(currentWord))
-					painter.fillRect(rect, QBrush(WORD_HIGHLIGHT_COLOR));
-			if (!currentError.isNull())
-				foreach (const QRect &rect, coordsToRects(currentError))
-					painter.fillRect(rect, QBrush(ERROR_HIGHLIGHT_COLOR));
+            painter.fillRect(currentLineRect(), QBrush(LINE_HIGHLIGHT_COLOR));
+            if (!currentWord.isNull()) {
+                const auto coordsToRectsList{coordsToRects(currentWord)};
+                for (const QRect &rect : coordsToRectsList)
+                    painter.fillRect(rect, QBrush(WORD_HIGHLIGHT_COLOR));
+            }
+            if (!currentError.isNull()) {
+                const auto coordsToRectsLst{coordsToRects(currentError)};
+                for (const QRect &rect : coordsToRectsLst)
+                    painter.fillRect(rect, QBrush(ERROR_HIGHLIGHT_COLOR));
+            }
 			painter.end();
 			QTextEdit::paintEvent(event);
 		}
@@ -201,7 +192,7 @@ class Editor : public QFrame
 
 	public:
 		explicit Editor(QWidget *parent = nullptr);
-		~Editor();
+		~Editor() override;
 
 		QTextEdit* view() const { return editor; }
 		QTextDocument* document() const { return editor->document(); }
@@ -228,7 +219,7 @@ class Editor : public QFrame
 		}
 
 
-	public slots:
+	public Q_SLOTS:
 		bool newFile();
 		bool openFile(const QUrl &url = QUrl());
 		void openExample(const QString& example, const QString& exampleName);
@@ -255,7 +246,7 @@ class Editor : public QFrame
 		void rehighlight() { highlighter->rehighlight(); }
 
 
-	signals:
+	Q_SIGNALS:
 		void contentNameChanged(const QString&);
 		void fileOpened(const QUrl&);
 		void fileSaved(const QUrl&);
@@ -264,15 +255,15 @@ class Editor : public QFrame
 		void cursorPositionChanged();
 
 
-	protected slots:
+	protected Q_SLOTS:
 		void textChanged(int pos, int added, int removed);
 // 		void cursorPositionChanged();
 
 	protected:
-		void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+		void paintEvent(QPaintEvent *event) override;
 
 
-	private slots:
+	private Q_SLOTS:
 		void updateOnCursorPositionChange();
 		void highlightCurrentLine() { this->update(); }
 
